@@ -14,13 +14,33 @@
 
 namespace Views {
 
+  class DatesEntry
+  {
+  public:
+    ::Data::DatePtr     date;
+    Lum::Base::Calendar startDate;
+    Lum::Base::Calendar endDate;
+
+  public:
+    DatesEntry(::Data::DatePtr date,
+               const Lum::Base::Calendar& startDate,
+               const Lum::Base::Calendar& endDate)
+    : date(date),startDate(startDate),endDate(endDate)
+    {
+      // no code
+    }
+  };
+
+  typedef Lum::Model::StdTable<DatesEntry*>     DatesEntryModel;
+  typedef Lum::Base::Reference<DatesEntryModel> DatesEntryModelRef;
+
   class Dates : public ::Base::View
   {
   private:
     Lum::Model::ActionRef    viewAction;
     Lum::Model::ActionRef    addAction;
     Lum::Model::ActionRef    deleteAction;
-    Lum::Model::ListTableRef model;
+    DatesEntryModelRef       model;
     Lum::Table               *table;
     Lum::Panel               *top;
 
